Documentation
¶
Index ¶
- Variables
- type CommandOptions
- func (*CommandOptions) Descriptor() ([]byte, []int)deprecated
- func (x *CommandOptions) GetArgsUsage() string
- func (x *CommandOptions) GetDescription() string
- func (x *CommandOptions) GetLongDescription() string
- func (x *CommandOptions) GetName() string
- func (x *CommandOptions) GetUsageText() string
- func (*CommandOptions) ProtoMessage()
- func (x *CommandOptions) ProtoReflect() protoreflect.Message
- func (x *CommandOptions) Reset()
- func (x *CommandOptions) String() string
- type FlagOptions
- func (*FlagOptions) Descriptor() ([]byte, []int)deprecated
- func (x *FlagOptions) GetName() string
- func (x *FlagOptions) GetRequired() bool
- func (x *FlagOptions) GetShorthand() string
- func (x *FlagOptions) GetUsage() string
- func (*FlagOptions) ProtoMessage()
- func (x *FlagOptions) ProtoReflect() protoreflect.Message
- func (x *FlagOptions) Reset()
- func (x *FlagOptions) String() string
- type ServiceConfigOptions
- func (*ServiceConfigOptions) Descriptor() ([]byte, []int)deprecated
- func (x *ServiceConfigOptions) GetConfigMessage() string
- func (*ServiceConfigOptions) ProtoMessage()
- func (x *ServiceConfigOptions) ProtoReflect() protoreflect.Message
- func (x *ServiceConfigOptions) Reset()
- func (x *ServiceConfigOptions) String() string
- type ServiceOptions
- func (*ServiceOptions) Descriptor() ([]byte, []int)deprecated
- func (x *ServiceOptions) GetArgsUsage() string
- func (x *ServiceOptions) GetDescription() string
- func (x *ServiceOptions) GetLongDescription() string
- func (x *ServiceOptions) GetName() string
- func (x *ServiceOptions) GetUsageText() string
- func (*ServiceOptions) ProtoMessage()
- func (x *ServiceOptions) ProtoReflect() protoreflect.Message
- func (x *ServiceOptions) Reset()
- func (x *ServiceOptions) String() string
Constants ¶
This section is empty.
Variables ¶
var ( // optional cli.v1.ServiceOptions service = 50000; E_Service = &file_cli_v1_cli_proto_extTypes[2] // optional cli.v1.ServiceConfigOptions service_config = 50003; E_ServiceConfig = &file_cli_v1_cli_proto_extTypes[3] )
Extension fields to descriptorpb.ServiceOptions.
var (
// optional cli.v1.CommandOptions command = 50001;
E_Command = &file_cli_v1_cli_proto_extTypes[0]
)
Extension fields to descriptorpb.MethodOptions.
var (
// optional cli.v1.FlagOptions flag = 50002;
E_Flag = &file_cli_v1_cli_proto_extTypes[1]
)
Extension fields to descriptorpb.FieldOptions.
var File_cli_v1_cli_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CommandOptions ¶
type CommandOptions struct {
// Custom name for the command (defaults to kebab-case of method name)
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Short one-line description shown in command lists and help summaries
// Best practice: Keep concise (e.g., "retrieve a user by ID")
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// Longer, detailed explanation of the command
// Use this for multi-paragraph documentation, examples, and detailed behavior
LongDescription string `protobuf:"bytes,3,opt,name=long_description,json=longDescription,proto3" json:"long_description,omitempty"`
// Custom usage text to override the auto-generated USAGE line
// Example: "get-user [options] <user-id>"
UsageText string `protobuf:"bytes,4,opt,name=usage_text,json=usageText,proto3" json:"usage_text,omitempty"`
// Description of arguments this command accepts
// Example: "<user-id>" or "[filter-expression]"
ArgsUsage string `protobuf:"bytes,5,opt,name=args_usage,json=argsUsage,proto3" json:"args_usage,omitempty"`
// contains filtered or unexported fields
}
CLI command annotation for RPC methods Customizes command name and help text following urfave/cli v3 best practices
func (*CommandOptions) Descriptor
deprecated
func (*CommandOptions) Descriptor() ([]byte, []int)
Deprecated: Use CommandOptions.ProtoReflect.Descriptor instead.
func (*CommandOptions) GetArgsUsage ¶
func (x *CommandOptions) GetArgsUsage() string
func (*CommandOptions) GetDescription ¶
func (x *CommandOptions) GetDescription() string
func (*CommandOptions) GetLongDescription ¶
func (x *CommandOptions) GetLongDescription() string
func (*CommandOptions) GetName ¶
func (x *CommandOptions) GetName() string
func (*CommandOptions) GetUsageText ¶
func (x *CommandOptions) GetUsageText() string
func (*CommandOptions) ProtoMessage ¶
func (*CommandOptions) ProtoMessage()
func (*CommandOptions) ProtoReflect ¶
func (x *CommandOptions) ProtoReflect() protoreflect.Message
func (*CommandOptions) Reset ¶
func (x *CommandOptions) Reset()
func (*CommandOptions) String ¶
func (x *CommandOptions) String() string
type FlagOptions ¶
type FlagOptions struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Shorthand string `protobuf:"bytes,2,opt,name=shorthand,proto3" json:"shorthand,omitempty"`
Usage string `protobuf:"bytes,3,opt,name=usage,proto3" json:"usage,omitempty"`
Required bool `protobuf:"varint,4,opt,name=required,proto3" json:"required,omitempty"`
// contains filtered or unexported fields
}
CLI flag annotation for message fields Maps message fields to CLI flags
func (*FlagOptions) Descriptor
deprecated
func (*FlagOptions) Descriptor() ([]byte, []int)
Deprecated: Use FlagOptions.ProtoReflect.Descriptor instead.
func (*FlagOptions) GetName ¶
func (x *FlagOptions) GetName() string
func (*FlagOptions) GetRequired ¶
func (x *FlagOptions) GetRequired() bool
func (*FlagOptions) GetShorthand ¶
func (x *FlagOptions) GetShorthand() string
func (*FlagOptions) GetUsage ¶
func (x *FlagOptions) GetUsage() string
func (*FlagOptions) ProtoMessage ¶
func (*FlagOptions) ProtoMessage()
func (*FlagOptions) ProtoReflect ¶
func (x *FlagOptions) ProtoReflect() protoreflect.Message
func (*FlagOptions) Reset ¶
func (x *FlagOptions) Reset()
func (*FlagOptions) String ¶
func (x *FlagOptions) String() string
type ServiceConfigOptions ¶
type ServiceConfigOptions struct {
// Name of the config message type (must be in same package)
ConfigMessage string `protobuf:"bytes,1,opt,name=config_message,json=configMessage,proto3" json:"config_message,omitempty"`
// contains filtered or unexported fields
}
Service config annotation Defines the configuration message type for a service
func (*ServiceConfigOptions) Descriptor
deprecated
func (*ServiceConfigOptions) Descriptor() ([]byte, []int)
Deprecated: Use ServiceConfigOptions.ProtoReflect.Descriptor instead.
func (*ServiceConfigOptions) GetConfigMessage ¶
func (x *ServiceConfigOptions) GetConfigMessage() string
func (*ServiceConfigOptions) ProtoMessage ¶
func (*ServiceConfigOptions) ProtoMessage()
func (*ServiceConfigOptions) ProtoReflect ¶
func (x *ServiceConfigOptions) ProtoReflect() protoreflect.Message
func (*ServiceConfigOptions) Reset ¶
func (x *ServiceConfigOptions) Reset()
func (*ServiceConfigOptions) String ¶
func (x *ServiceConfigOptions) String() string
type ServiceOptions ¶
type ServiceOptions struct {
// Custom name for the service command (defaults to kebab-case of service name)
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Short one-line description shown in service lists
// Best practice: Keep concise (e.g., "user management commands")
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// Longer, detailed explanation of the service
// Use this for multi-paragraph documentation and service overview
LongDescription string `protobuf:"bytes,3,opt,name=long_description,json=longDescription,proto3" json:"long_description,omitempty"`
// Custom usage text to override the auto-generated USAGE line
UsageText string `protobuf:"bytes,4,opt,name=usage_text,json=usageText,proto3" json:"usage_text,omitempty"`
// Description of arguments this service accepts
ArgsUsage string `protobuf:"bytes,5,opt,name=args_usage,json=argsUsage,proto3" json:"args_usage,omitempty"`
// contains filtered or unexported fields
}
Service options annotation Defines CLI customization for a service following urfave/cli v3 best practices
func (*ServiceOptions) Descriptor
deprecated
func (*ServiceOptions) Descriptor() ([]byte, []int)
Deprecated: Use ServiceOptions.ProtoReflect.Descriptor instead.
func (*ServiceOptions) GetArgsUsage ¶
func (x *ServiceOptions) GetArgsUsage() string
func (*ServiceOptions) GetDescription ¶
func (x *ServiceOptions) GetDescription() string
func (*ServiceOptions) GetLongDescription ¶
func (x *ServiceOptions) GetLongDescription() string
func (*ServiceOptions) GetName ¶
func (x *ServiceOptions) GetName() string
func (*ServiceOptions) GetUsageText ¶
func (x *ServiceOptions) GetUsageText() string
func (*ServiceOptions) ProtoMessage ¶
func (*ServiceOptions) ProtoMessage()
func (*ServiceOptions) ProtoReflect ¶
func (x *ServiceOptions) ProtoReflect() protoreflect.Message
func (*ServiceOptions) Reset ¶
func (x *ServiceOptions) Reset()
func (*ServiceOptions) String ¶
func (x *ServiceOptions) String() string